==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/sl_SI.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG urejevalnik';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['stripbackgroundtags'] = 'Poreži oznake za ozadje iz CSS';
$lang['source_formatting_text'] = 'Pripni izvorno oblikovanje izhodnemu HTML';
$lang['dropdownblockformats_text'] = 'Formati blokov v izvlečnem meniju';
$lang['allowtables'] = 'Dovoli operacije s tabelami';
$lang['newlinestyle_text'] = 'Tip nove vrstice';
$lang['pstyle'] = 'p stil (odstavek)';
$lang['brstyle'] = 'br stil (nova vrstica)';
$lang['usecompressiontext'] = 'Uporabi GZ kompresijo';
$lang['usecompressionhelp'] = 'Možnost lahko pohitri delovanje TinyMCE urejevalnika, vendar lahko povzroči težave z delovanjem na nekaterih sistemih. Uporabljajte s previdnostjo.';
$lang['forcedrootblocktext'] = 'Vsili <p> blok korena';
$lang['forcedrootblockhelp'] = 'Vrnjene vsebine omeji z oznako <p>';
$lang['filepickerstyle'] = 'Stil izbiralca datotek';
$lang['filepickersize'] = 'Velikost izbiralca datotek';
$lang['allowuploadtext'] = 'Omogoči prenos in ustvarjanje map v izbiralcu datotek';
$lang['cannotreadconfig'] = 'Ne morem prebrati datoteke tinyconfig.php, zato TinyMCE urejevalnik najverjetneje ne bo deloval pravilno. Prosimo, preverite pravice datoteke in nadrejenih map, ki morajo biti berljive (ne pa zapisljive) s strani lastnika.';
$lang['filenameonly'] = 'Prikaži imena datotek';
$lang['thumbnailsonly'] = 'Prikaži ikone';
$lang['filenameandthumbnails'] = 'Prikaži imena datotek in ikone';
$lang['skinstext'] = 'Izgled';
$lang['skinvariationtext'] = 'Različica izgleda';
$lang['advancedwarning'] = '<strong>Please note!<br/>Changing these settings can cause TinyMCE to stop working or the generated code to be wrong in some way. Only edit this if you know what you are doing! Please consult the TinyMCE website before playing with this.</strong>';
$lang['entityencoding_text'] = 'Encoding of entities';
$lang['rawencoding'] = 'Raw encoding (fastest, works in most cases)';
$lang['namedencoding'] = 'Named encoding (like &nbsp;)';
$lang['numericencoding'] = 'Numeric encoding (like &amp;#160;)';
$lang['show_path_text'] = 'Show the path of the element at the bottom of the editor';
$lang['toolbar_tab'] = 'Toolbar';
$lang['toolbar_help'] = 'These options should contain a comma separated list of button/control names to insert into the toolbar.';
$lang['toolbar_text'] = 'Toolbar';
$lang['toolbarhelptext'] = 'Click here to view toolbar-instructions in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Width of editor field';
$lang['editor_height_text'] = 'Height of editor field';
$lang['auto'] = 'Auto';
$lang['or'] = 'or';
$lang['datetimeformat_text'] = 'Date/Time format';
$lang['timetext'] = 'Time';
$lang['datetext'] = 'Date';
$lang['datetimeformat_help'] = 'Click here for help on how to format the date/time';
$lang['extraconfigtext'] = 'Extra configuration';
$lang['extraconfighelp'] = 'Check TinyMCE-wiki for instructions';
$lang['customdropdowntext'] = 'Custom dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Load the CMS-linker';
$lang['loadcmslinkerhelp'] = 'This generates the javascript-code needed to allow &#039;cmslinker&#039; to be added to a toolbar.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style';
$lang['cmsselflinkstyle'] = '{cms_selflink}-style';
$lang['ahrefstyle'] = '<a href>-style';
$lang['relativeurlstext'] = 'Generate relative urls';
$lang['forcecleanpastetext'] = 'Force clean on paste';
$lang['forcecleanpastehelp'] = 'This should be enabled to remove strange formatting codes when pasting from Word etc.';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'Will be added to the css body-definition';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Use static config file';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'Show checkbox to turn wysiwyg on/off';
$lang['togglewysiwyg'] = 'Vklopi/izklopi vizualni urejevalnik';
$lang['styles_tab'] = 'CSS Styles';
$lang['styles_help'] = '  If you leave the field empty, TinyMCE will parse your CSS file and list the class styles contained in it to the user. 
  If you want only some styles presented to the user, specify them in the form &quot;CustomName1=style1; CustomName2=style2&quot;, 
  &quot;style1&quot; being a class call in your stylesheet and you don&#039;t put the . 
  normally used for class calls as it is already in your CSS, it will look like this <span class=&quot;style1&quot;>text</span>, 
  in the first field below. 
';
$lang['css_styles_text'] = 'Styles';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['submit'] = 'Submit';
$lang['update'] = 'Update';
$lang['settings'] = 'Settings';
$lang['settingssaved'] = 'Settings was saved';
$lang['advancedsaved'] = 'Advanced settings saved';
$lang['toolbarsaved'] = 'Toolbar was saved';
$lang['stylessaved'] = 'Styles was saved';
$lang['testareatext'] = 'Test area, no content will be harmed playing with this...';
$lang['reset'] = 'Reset defaults';
$lang['resetall'] = 'Reset all settings to defaults';
$lang['confirmreset'] = 'Are you sure you want to reset these settings to their defaults?';
$lang['confirmresetall'] = 'Are you sure you want to reset ALL settings to their defaults?';
$lang['settingsreset'] = 'These settings was reset to default';
$lang['allsettingsreset'] = 'All settings was reset to default';
$lang['upgraded'] = 'has been upgraded to version %s';
$lang['customdropdown'] = 'Prilagojeni izvlečni meni';
$lang['cmsmslinker'] = 'Vstavi povezavo na CMS stran';
$lang['backend_toolbars'] = 'Backend toolbar settings';
$lang['frontend_toolbars'] = 'Frontend toolbar settings';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Save plugins';
$lang['pluginssaved'] = 'Plugins saved';
$lang['youareintext'] = 'Nahajate se v';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'Nova datoteka';
$lang['uploadfile'] = 'Naloži';
$lang['createnewdir'] = 'Nova mapa';
$lang['createdir'] = 'Ustvari';
$lang['nodirname'] = 'Ime mape ni podano';
$lang['direxists'] = 'Mapa s tem imenom že obstaja';
$lang['newdircreated'] = 'Nova mapa je bila ustvarjena';
$lang['newdirfailed'] = 'Napaka pri ustvarjanju nove mape';
$lang['nofile'] = 'Nobena datoteka ni bila naložena';
$lang['filetoobig'] = 'Naložena datoteka je prevelika';
$lang['uploadfailed'] = 'Napaka pri premikanju naložene datoteke na njeno mesto';
$lang['fileuploaded'] = 'Datoteka je bila uspe&scaron;no name&scaron;čena';
$lang['filepickertitle'] = 'CMS izbira datotek';
$lang['success'] = 'Uspe&scaron;no';
$lang['fileoperations'] = 'Operacije z datotekami';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Velikost';
$lang['dimensions'] = '&Scaron;xV';
$lang['advanced_tab'] = 'Napredno';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	</ul>
	<br/>
		
';
$lang['utma'] = '156861353.587959277.1217433595.1222588216.1226677167.21';
$lang['utmz'] = '156861353.1222588216.20.11.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/sl_SI.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG urejevalnik';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['stripbackgroundtags'] = 'Poreži oznake za ozadje iz CSS';
$lang['source_formatting_text'] = 'Pripni izvorno oblikovanje izhodnemu HTML';
$lang['dropdownblockformats_text'] = 'Formati blokov v izvlečnem meniju';
$lang['allowtables'] = 'Dovoli operacije s tabelami';
$lang['newlinestyle_text'] = 'Tip nove vrstice';
$lang['pstyle'] = 'p stil (odstavek)';
$lang['brstyle'] = 'br stil (nova vrstica)';
$lang['usecompressiontext'] = 'Uporabi GZ kompresijo';
$lang['usecompressionhelp'] = 'Možnost lahko pohitri delovanje TinyMCE urejevalnika, vendar lahko povzroči težave z delovanjem na nekaterih sistemih. Uporabljajte s previdnostjo.';
$lang['forcedrootblocktext'] = 'Vsili <p> blok korena';
$lang['forcedrootblockhelp'] = 'Vrnjene vsebine omeji z oznako <p>';
$lang['filepickerstyle'] = 'Stil izbiralca datotek';
$lang['filepickersize'] = 'Velikost izbiralca datotek';
$lang['allowuploadtext'] = 'Omogoči prenos in ustvarjanje map v izbiralcu datotek';
$lang['cannotreadconfig'] = 'Ne morem prebrati datoteke tinyconfig.php, zato TinyMCE urejevalnik najverjetneje ne bo deloval pravilno. Prosimo, preverite pravice datoteke in nadrejenih map, ki morajo biti berljive (ne pa zapisljive) s strani lastnika.';
$lang['filenameonly'] = 'Prikaži imena datotek';
$lang['thumbnailsonly'] = 'Prikaži ikone';
$lang['filenameandthumbnails'] = 'Prikaži imena datotek in ikone';
$lang['skinstext'] = 'Izgled';
$lang['skinvariationtext'] = 'Različica izgleda';
$lang['advancedwarning'] = '<strong>Please note!<br/>Changing these settings can cause TinyMCE to stop working or the generated code to be wrong in some way. Only edit this if you know what you are doing! Please consult the TinyMCE website before playing with this.</strong>';
$lang['entityencoding_text'] = 'Encoding of entities';
$lang['rawencoding'] = 'Raw encoding (fastest, works in most cases)';
$lang['namedencoding'] = 'Named encoding (like &nbsp;)';
$lang['numericencoding'] = 'Numeric encoding (like &amp;#160;)';
$lang['show_path_text'] = 'Show the path of the element at the bottom of the editor';
$lang['toolbar_tab'] = 'Toolbar';
$lang['toolbar_help'] = 'These options should contain a comma separated list of button/control names to insert into the toolbar.';
$lang['toolbar_text'] = 'Toolbar';
$lang['toolbarhelptext'] = 'Click here to view toolbar-instructions in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Width of editor field';
$lang['editor_height_text'] = 'Height of editor field';
$lang['auto'] = 'Auto';
$lang['or'] = 'or';
$lang['datetimeformat_text'] = 'Date/Time format';
$lang['timetext'] = 'Time';
$lang['datetext'] = 'Date';
$lang['datetimeformat_help'] = 'Click here for help on how to format the date/time';
$lang['extraconfigtext'] = 'Extra configuration';
$lang['extraconfighelp'] = 'Check TinyMCE-wiki for instructions';
$lang['customdropdowntext'] = 'Custom dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup enabled';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Load the CMS-linker';
$lang['loadcmslinkerhelp'] = 'This generates the javascript-code needed to allow &#039;cmslinker&#039; to be added to a toolbar.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style';
$lang['cmsselflinkstyle'] = '{cms_selflink}-style';
$lang['ahrefstyle'] = '<a href>-style';
$lang['relativeurlstext'] = 'Generate relative urls';
$lang['forcecleanpastetext'] = 'Force clean on paste';
$lang['forcecleanpastehelp'] = 'This should be enabled to remove strange formatting codes when pasting from Word etc.';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'Will be added to the css body-definition';
$lang['includeonlyscreencss_text'] = 'Include only screen CSS';
$lang['includeonlyscreencss_help'] = 'Selecting this allows only attached stylesheets with the screen-mediatype selected to be included in the styles TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Use static config file';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the static config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'Show checkbox to turn wysiwyg on/off';
$lang['togglewysiwyg'] = 'Vklopi/izklopi vizualni urejevalnik';
$lang['styles_tab'] = 'CSS Styles';
$lang['styles_help'] = '  If you leave the field empty, TinyMCE will parse your CSS file and list the class styles contained in it to the user. 
  If you want only some styles presented to the user, specify them in the form &quot;CustomName1=style1; CustomName2=style2&quot;, 
  &quot;style1&quot; being a class call in your stylesheet and you don&#039;t put the . 
  normally used for class calls as it is already in your CSS, it will look like this <span class=&quot;style1&quot;>text</span>, 
  in the first field below. 
';
$lang['css_styles_text'] = 'Styles';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['submit'] = 'Submit';
$lang['update'] = 'Update';
$lang['settings'] = 'Settings';
$lang['settingssaved'] = 'Settings was saved';
$lang['advancedsaved'] = 'Advanced settings saved';
$lang['toolbarsaved'] = 'Toolbar was saved';
$lang['stylessaved'] = 'Styles was saved';
$lang['testareatext'] = '<p>Test area, no content will be harmed playing with this...</p>';
$lang['reset'] = 'Reset defaults';
$lang['resetall'] = 'Reset all settings to defaults';
$lang['confirmreset'] = 'Are you sure you want to reset these settings to their defaults?';
$lang['confirmresetall'] = 'Are you sure you want to reset ALL settings to their defaults?';
$lang['settingsreset'] = 'These settings was reset to default';
$lang['allsettingsreset'] = 'All settings was reset to default';
$lang['upgraded'] = 'has been upgraded to version %s';
$lang['customdropdown'] = 'Prilagojeni izvlečni meni';
$lang['cmsmslinker'] = 'Vstavi povezavo na CMS stran';
$lang['backend_toolbars'] = 'Backend toolbar settings';
$lang['frontend_toolbars'] = 'Frontend toolbar settings';
$lang['plugins_tab'] = 'Plugins';
$lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
$lang['plugins_text'] = 'Plugins';
$lang['saveplugins'] = 'Save plugins';
$lang['pluginssaved'] = 'Plugins saved';
$lang['youareintext'] = 'Nahajate se v';
$lang['extrastylestext'] = 'Additions to stylesheet';
$lang['extrastyleshelp'] = 'CSS entered here will be added to the stylesheet read by TinyMCE after it recieves the CMSms styles';
$lang['uploadnewfile'] = 'Nova datoteka';
$lang['uploadfile'] = 'Naloži';
$lang['createnewdir'] = 'Nova mapa';
$lang['createdir'] = 'Ustvari';
$lang['nodirname'] = 'Ime mape ni podano';
$lang['direxists'] = 'Mapa s tem imenom že obstaja';
$lang['newdircreated'] = 'Nova mapa je bila ustvarjena';
$lang['newdirfailed'] = 'Napaka pri ustvarjanju nove mape';
$lang['nofile'] = 'Nobena datoteka ni bila naložena';
$lang['filetoobig'] = 'Naložena datoteka je prevelika';
$lang['uploadfailed'] = 'Napaka pri premikanju naložene datoteke na njeno mesto';
$lang['fileuploaded'] = 'Datoteka je bila uspe&scaron;no name&scaron;čena';
$lang['filepickertitle'] = 'CMS izbira datotek';
$lang['success'] = 'Uspe&scaron;no';
$lang['fileoperations'] = 'Operacije z datotekami';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Velikost';
$lang['dimensions'] = '&Scaron;xV';
$lang['advanced_tab'] = 'Napredno';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	</ul>
	<br/>
		
';
$lang['utma'] = '156861353.587959277.1217433595.1222588216.1226677167.21';
$lang['utmz'] = '156861353.1222588216.20.11.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
